'------------------------------------------------------------------------
' Folder Scripting (v1.1)
'------------------------------------------------------------------------
' Scripting methods for returning counts / details / sizes of folders and
' file within a sleected directory
' 
' Variables:
'	ParentFolder = The Folder you wish to scan
'	SubFolders = Enter value true to recurse Sub Folders
'	FileExtensions = Enter File extensions, split by comma
'				Blank = All Files
'				avi,mp3 = movies And mp3s
'	FullPath = Enter true to shows the full file path not just filename
'	ShowExtension = Enter true to show extension else autohides
'	SortResults = Enter true to sort the results aphabetically
'	DivideBy = Divide the bytes by 1024/KB 1048756/MB etc
'
'
' UPDATES
' 08 April 2005
' Filters by multiple file extensions
' Can sort Aphabetically
' Shows / hides File Extension
' Shows File Path / Name
' 					                       - mnorth
'------------------------------------------------------------------------

'------------------------------------------------------------------------
' Global static variable for sub folders
'------------------------------------------------------------------------
Dim Output

'------------------------------------------------------------------------
' Returns a count of all the sub folders contained in parent folder
'------------------------------------------------------------------------
Function FolderCount(ParentFolder, SubFolders)
	Set fs = CreateObject("Scripting.FileSystemObject")
	Set ThisFolder = fs.GetFolder(ParentFolder)

	Output = Output + ThisFolder.SubFolders.Count
	If lcase(SubFolders) = "true" Then
		Set AllFolders = ThisFolder.SubFolders
		For Each Folder In AllFolders
			If Folder.Attributes <> 22 Then _
			temp = FolderCount(Folder.Path, SubFolders)
		Next
	End If
	FolderCount = Output
		
	Set fs = Nothing
	Set ThisFolder = Nothing
	Set AllFolders = Nothing
End Function

'------------------------------------------------------------------------
' Returns a list of all the sub folders contained in parent folder
'------------------------------------------------------------------------
Function FolderDetail(ParentFolder, SubFolders, FullPath, SortResults)
	FolderDetail = GetFolderDetail(ParentFolder, SubFolders, FullPath)
	If LCase(SortResults) = "true" Then _
		FolderDetail = CombSort(FolderDetail)
End Function

Private Function GetFolderDetail(ParentFolder, SubFolders, FullPath)
	Set fs=CreateObject("Scripting.FileSystemObject")
	Set ThisFolder = fs.GetFolder(ParentFolder)
	Set AllFolders = ThisFolder.SubFolders

	For Each Folder In AllFolders
		If lcase(FullPath) = "true" Then
			output = output & Folder.Path & vbCr
		Else
			output = output & Folder.Name & vbCr
		End If
	Next
	If lcase(SubFolders) = "true" Then
		For Each Folder In AllFolders
			If Folder.Attributes <> 22 Then _
			temp = GetFolderDetail(Folder.Path, SubFolders, FullPath)
		Next
	End If
	GetFolderDetail = output
	
	Set fs = Nothing
	Set ThisFolder = Nothing
	Set AllFolders = Nothing
End Function

'------------------------------------------------------------------------
' Returns a count of all the files contained in parent folder
'------------------------------------------------------------------------
Function FileCount(ParentFolder, SubFolders, FileExtensions)
	Output = 0
	FileExtensions = Split(FileExtensions, ","):
	FileCount = GetFileCount(ParentFolder, SubFolders, FileExtensions)
End Function

Private Function GetFileCount(ParentFolder, SubFolders, FileExtensions)
	Set fs=CreateObject("Scripting.FileSystemObject")
	Set ThisFolder = fs.GetFolder(ParentFolder)
	
	
	If lcase(SubFolders) = "true" Then
		Set AllFolders = ThisFolder.SubFolders
		For Each Folder In AllFolders
			If Folder.Attributes <> 22 Then _
			temp = GetFileCount(Folder.Path, "true", FileExtensions)
		Next
	End If
	
	'LOOPS EXTENSIONS CHECKING
	If Ubound(FileExtensions) = -1 Then
		Output = Output + ThisFolder.Files.Count	
	Else
		Set AllFiles = ThisFolder.Files
		For Each File In AllFiles
			For Each Extension In FileExtensions
				If mid(File.Name, len(File.Name) - 2) = LCase(Extension) Then _
					Output = Output + 1
			Next
		Next
	End If
	
	GetFileCount = Output
	
	Set fs = Nothing
	Set ThisFolder = Nothing
End Function

'------------------------------------------------------------------------
' Returns a list of all the sub folders contained in parent folder
'------------------------------------------------------------------------
Function FileDetail(ParentFolder, SubFolders, FileExtensions, FullPath, ShowExtension, SortResults)
	FileExtensions = Split(FileExtensions, ",")
	FileDetail = GetFileDetail(ParentFolder, SubFolders, FullPath, FileExtensions, ShowExtension)
	If LCase(SortResults) = "true" Then _
		FileDetail = CombSort(FileDetail)
End Function

Private Function GetFileDetail(ParentFolder, SubFolders, FullPath, FileExtensions, ShowExtension)
	Set fs=CreateObject("Scripting.FileSystemObject")
	Set ThisFolder = fs.GetFolder(ParentFolder)
	Set AllFiles = ThisFolder.Files

	If LCase(SubFolders) = "true" Then
		Set AllFolders = ThisFolder.SubFolders
		For Each Folder In AllFolders
			If Folder.Attributes <> 22 Then _
			temp = GetFileDetail(Folder.Path, "true", FullPath, FileExtensions, ShowExtension)
		Next
	End If
	For Each File In AllFiles
		If Ubound(FileExtensions)= - 1 Then
			If LCase(FullPath) = "true" Then
				output = output & File.Path
			Else
				output = output & File.Name
			End If
			If LCase(ShowExtension <> "true") Then _
				output = mid(output, 1, len(output) - 4)
			output = output & vbCr
		Else
			For Each Extension In FileExtensions
				If mid(File.Name, len(File.Name) - 2) = LCase(Extension) Then
					If LCase(FullPath) = "true" Then
						output = output & File.Path
					Else
						output = output & File.Name
					End If
					If LCase(ShowExtension <> "true") Then _
						output = mid(output, 1, len(output) - 4)
					output = output & vbCr
				End If
			Next
		End If
	Next

	GetFileDetail = output
	
	Set fs = Nothing
	Set ThisFolder = Nothing
	Set AllFiles = Nothing
End Function

'------------------------------------------------------------------------
' Returns a the size of all the files contained in parent folder
'------------------------------------------------------------------------
Function FileSize(ParentFolder, SubFolders, DividedBy, FileExtensions)
	FileExtensions = Split(FileExtensions, ",")
	FileSize = GetFileSize(ParentFolder, SubFolders, DividedBy, FileExtensions)
End Function

Private Function GetFileSize(ParentFolder, SubFolders, DividedBy, FileExtensions)
	Set fs=CreateObject("Scripting.FileSystemObject")
	Set ThisFolder = fs.GetFolder(ParentFolder)
	Set AllFiles = ThisFolder.Files

	If LCase(SubFolders = "true") Then
		Set AllFolders = ThisFolder.SubFolders
		For Each Folder In AllFolders
			If Folder.Attributes <> 22 Then _
			temp = GetFileSize(Folder.Path, "true", DividedBy, FileExtensions)
		Next
	End If
	For Each File In AllFiles
		If Ubound(FileExtensions) = -1 Then
			output = output + File.Size
		Else
			For Each Extension In FileExtensions
				If mid(File.Name, len(File.Name) - 2) = LCase(Extension) Then _
					output = output + File.Size	
			Next
		End If
	Next
	GetFileSize = output / DividedBy
	
	Set fs = Nothing
	Set ThisFolder = Nothing
	Set AllFiles = Nothing
End Function

'------------------------------------------------------------------------
'CUSTOM METHOD TO SORT RESULTS
'------------------------------------------------------------------------
Private Function CombSort(Byval InputString)
	Dim UnsortedArray
	Dim I, J, Temp, Gap, Swapped
	Dim ArrSize, Combcom, Combswap
	Const Shrink = 1.3
	
	UnsortedArray = Split(InputString, vbCr)
	Redim Preserve UnsortedArray(Ubound(UnsortedArray) - 1)
	ArrSize = UBOUND( UnsortedArray )
	Gap = Arrsize - 1
	Do
		Gap = Int(Gap / Shrink)
		Swapped = True
		Combcom = Combcom + 1
		For J = 0 To Arrsize - Gap
			If UnsortedArray(J) > UnsortedArray(J + Gap) Then
				Temp = UnsortedArray(J)
				UnsortedArray(J) = UnsortedArray(J + Gap)
				UnsortedArray(J + Gap) = Temp
				Swapped = False
				Combswap = Combswap + 1
			End If
		Next
	Loop Until Not Swapped And Gap = 1
	
	CombSort = Join(UnsortedArray,vbCr)
End Function